__doc__ = """
ndcpyr
========
Пакет, создаваемый для работы с данными на платформе Национального центра социально-экономических данных (НЦСЭД).
"""

__author__ = """Алина Владимирова"""
__version__ = "0.1.0"

from . import preprocessing  # noqa : F401